<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>MainWindow</name>
    <message>
        <source>MX Welcome</source>
        <translation type="vanished">MX Karşılama</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="33"/>
        <source>&amp;Copy for forum</source>
        <translation>Forum için &amp;kopyala</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="47"/>
        <source>Save the displayed system information to a text file.</source>
        <translation>Gösterilen sistem bilgisini bir metin dosyasına kaydedin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="50"/>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Save text...</source>
        <translation>Metni kaydet...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="30"/>
        <source>Copy the displayed system information to the clipboard, encased in [CODE][/CODE] tags ready to use in a forum post.</source>
        <translation>Görüntülenen sistem bilgilerini, bir forum gönderisinde kullanılmaya hazır [CODE][/CODE] etiketleri içinde panoya kopyalayın.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="199"/>
        <source>Save the system information selected from the list to an archive file.</source>
        <translation>Listeden seçilen sistem bilgilerini bir arşiv dosyasına kaydedin.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="202"/>
        <location filename="../mainwindow.cpp" line="137"/>
        <source>&amp;Save...</source>
        <translation>&amp;Kaydet...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="102"/>
        <source>Quit application</source>
        <translation>Uygulamadan çık</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="105"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="154"/>
        <source>About this application</source>
        <translation>Uygulama hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="157"/>
        <source>About...</source>
        <translation>Hakkında...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="164"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>Journald</source>
        <extracomment>systemd journalctl tab</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="262"/>
        <source>Log Type</source>
        <extracomment>type of log, either user level or system</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="270"/>
        <source>System</source>
        <extracomment>system level log</extracomment>
        <translation>Sistem</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="275"/>
        <source>User</source>
        <extracomment>user level log</extracomment>
        <translation>Kullanıcı</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="283"/>
        <source>Priority Level</source>
        <extracomment>level of status message to view</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Choose Boot Log</source>
        <extracomment>choose a boot to view the log</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Service Search</source>
        <extracomment>seek and ye shall find</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="199"/>
        <source>Version: </source>
        <translation>Sürüm:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <location filename="../mainwindow.cpp" line="199"/>
        <location filename="../mainwindow.cpp" line="344"/>
        <location filename="../mainwindow.cpp" line="374"/>
        <source>Quick System Info</source>
        <translation>Hızlı Sistem Bilgisi</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="61"/>
        <source>Loading...</source>
        <translation>Yükleniyor...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="203"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Telif Hakkı (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="198"/>
        <source>About Quick-System-Info-gui</source>
        <translation>Quick-System-Info-gui Hakkında</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="96"/>
        <source>&amp;Find...</source>
        <translation>&amp;Bul...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="100"/>
        <location filename="../mainwindow.cpp" line="510"/>
        <source>Find &amp;Next</source>
        <translation>&amp;Sonrakini Bul</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="126"/>
        <source>Select &amp;All</source>
        <translation>&amp;Tümünü Seç</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="132"/>
        <source>Revert Selection</source>
        <translation>Seçimi Çevir</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <source>Program for displaying a quick system info report</source>
        <translation>Hızlı bir sistem bilgisi raporu görüntülemek için program</translation>
    </message>
    <message>
        <source>License</source>
        <translation type="vanished">Lisans</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="205"/>
        <source>%1 License</source>
        <translation>%1 Lisans</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="299"/>
        <source>Open folder</source>
        <translation>Açık dosya</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="301"/>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="468"/>
        <source>&amp;Save (×%1)...</source>
        <translation>&amp;Kaydet (×%1)...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>Find</source>
        <translation>Bul</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="506"/>
        <source>&amp;Find what:</source>
        <translation>&amp;Neyi bul:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="516"/>
        <source>Match c&amp;ase</source>
        <translation>Küçük/büyük &amp;duyarlı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="517"/>
        <source>Match &amp;whole word only</source>
        <translation>Sadece &amp;tam sözcüğü eşleştir</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="520"/>
        <source>Direction</source>
        <translation>Yön</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="522"/>
        <source>&amp;Up</source>
        <translation>&amp;Yukarı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="523"/>
        <source>&amp;Down</source>
        <translation>&amp;Aşağı</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="568"/>
        <location filename="../mainwindow.cpp" line="573"/>
        <source>Cannot find &quot;%1&quot;</source>
        <translation>&quot;%1&quot; bulunamıyor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="710"/>
        <source>No journal entries found at this admin and priority level</source>
        <comment>no journal entries found at the options specified</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="712"/>
        <source>Error running journalctl command</source>
        <comment>error report for journalctl command</comment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Changelog</source>
        <translation type="vanished">Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">&amp;Kapat</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>Save System Information</source>
        <translation>Sistem Bilgilerini Kaydet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="298"/>
        <source>System information saved.</source>
        <translation>Sistem bilgisi kaydedildi.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Could not save system information.</source>
        <translation>Sistem bilgileri kaydedilemedi.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="351"/>
        <source>history</source>
        <translation>geçmiş</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="374"/>
        <source>%1 Help</source>
        <translation>%1 Yardım</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="82"/>
        <source>Copy for forum</source>
        <translation>Forum için Kopyala</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="87"/>
        <source>Plain text copy</source>
        <translation>Düz metin kopyala</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>You must run this program as normal user.</source>
        <translation>Bu programı normal kullanıcı olarak çalıştırmalısınız.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="43"/>
        <source>This tool displays a the quick system info report in a gui.</source>
        <translation>Bu araç, grafik arayüzde hızlı sistem bilgisi raporunu görüntüler.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="66"/>
        <source>Error</source>
        <translation>Hata</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="40"/>
        <source>License</source>
        <translation>Lisans</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="41"/>
        <location filename="../about.cpp" line="51"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="63"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
</context>
</TS>